@@ -88,14 +88,16 @@ class DocumentRouter:
                 event_page = pack_event_page(doc)
                 # Subclass' implementation of event_page may return a valid
                 # EventPage or None or NotImplemented.
-                output_event_page = self.event_page(event_page) or event_page
+                output_event_page = self.event_page(event_page)
+                output_event_page = output_event_page if output_event_page is not None else event_page
                 if output_event_page is not NotImplemented:
                     output_doc, = unpack_event_page(output_event_page)
             elif name == 'datum':
                 datum_page = pack_datum_page(doc)
                 # Subclass' implementation of datum_page may return a valid
                 # DatumPage or None or NotImplemented.
-                output_datum_page = self.datum_page(datum_page) or datum_page
+                output_datum_page = self.datum_page(datum_page)
+                output_datum_page = output_datum_page if output_datum_page is not None else datum_page
                 if output_datum_page is not NotImplemented:
                     output_doc, = unpack_datum_page(output_datum_page)
             elif name == 'event_page':
@@ -103,7 +105,8 @@ class DocumentRouter:
                 for event in unpack_event_page(doc):
                     # Subclass' implementation of event may return a valid
                     # Event or None or NotImplemented.
-                    output_event = self.event(event) or event
+                    output_event = self.event(event)
+                    output_event = output_event if output_event is not None else event
                     if output_event is NotImplemented:
                         break
                     output_events.append(output_event)
@@ -114,7 +117,8 @@ class DocumentRouter:
                 for datum in unpack_datum_page(doc):
                     # Subclass' implementation of datum may return a valid
                     # Datum or None or NotImplemented.
-                    output_datum = self.datum(datum) or datum
+                    output_datum = self.datum(datum)
+                    output_datum = output_datum if output_datum is not None else datum
                     if output_datum is NotImplemented:
                         break
                     output_datums.append(output_datum)
@@ -442,6 +446,61 @@ class Filler(DocumentRouter):
         self.retry_intervals = retry_intervals
         self._closed = False
 
+    def __eq__(self, other):
+        return (
+            type(self) is type(other) and
+            self.inplace == other.inplace and
+            self._coerce == other._coerce and
+            self.include == other.include and
+            self.exclude == other.exclude and
+            self.root_map == other.root_map and
+            type(self._handler_cache) is type(other._handler_cache) and
+            type(self._resource_cache) is type(other._resource_cache) and
+            type(self._datum_cache) is type(other._datum_cache) and
+            type(self._descriptor_cache) is type(other._descriptor_cache) and
+            self.retry_intervals == other.retry_intervals
+        )
+
+    def __getstate__(self):
+        return dict(
+            inplace=self._inplace,
+            coersion_func=self._coerce,
+            handler_registry=self._unpatched_handler_registry,
+            include=self.include,
+            exclude=self.exclude,
+            root_map=self.root_map,
+            handler_cache=self._handler_cache,
+            resource_cache=self._resource_cache,
+            datum_cache=self._datum_cache,
+            descriptor_cache=self._descriptor_cache,
+            retry_intervals=self.retry_intervals)
+
+    def __setstate__(self, d):
+        self._inplace = d['inplace']
+        self._coerce = d['coersion_func']
+
+        # See comments on coerision functions above for the use of
+        # _current_state, which is passed to coersion functions' `filler_state`
+        # parameter.
+        self._current_state = threading.local()
+        self._unpatched_handler_registry = {}
+        self._handler_registry = {}
+        for spec, handler_class in d['handler_registry'].items():
+            self.register_handler(spec, handler_class)
+        self.handler_registry = HandlerRegistryView(self._handler_registry)
+        self.include = d['include']
+        self.exclude = d['exclude']
+        self.root_map = d['root_map']
+        self._handler_cache = d['handler_cache']
+        self._resource_cache = d['resource_cache']
+        self._datum_cache = d['datum_cache']
+        self._descriptor_cache = d['descriptor_cache']
+        retry_intervals = d['retry_intervals']
+        if retry_intervals is None:
+            retry_intervals = []
+        self._retry_intervals = retry_intervals
+        self._closed = False
+
     @property
     def retry_intervals(self):
         return self._retry_intervals
@@ -1241,6 +1300,7 @@ for name, filename in SCHEMA_NAMES.items():
 
 def _is_array(checker, instance):
     return (
+        isinstance(instance, numpy.ndarray) or
         jsonschema.validators.Draft7Validator.TYPE_CHECKER.is_type(instance, 'array') or
         isinstance(instance, tuple)
     )
